@@ -219,14 +219,18 @@ def find_installed_cmake_qibuild_dir(python_dir):
     for candidate in [
         # python in qibuild/python, cmake in qibuild/cmake
         ("..", "..", "cmake"),
-        # python in lib/python-2.7/dist,site}-packages,
-        #  cmake in share/cmake/
-        #  (default pip)
+        # python in lib/python-2.7/{dist,site}-packages,
+        # cmake in share/cmake/
+        # (default pip)
         ("..", "..", "..", "..", "share", "cmake"),
         # python in local/lib/python-2.7/{dist,site}-packages,
         # cmake in share/cmake
         # (debian's pip)
         ("..", "..", "..", "..", "..", "share", "cmake"),
+        # python in Python27\Lib\{dist,site}-packages
+        # cmake in Python27\share\cmake
+        # (windows' pip)
+        ("..", "..", "..", "share", "cmake")
         ]:
         rel_path = os.path.join(*candidate)
         res = os.path.join(python_dir, rel_path)
